# Word Hunt Solver

A minimalistic solver for iMessage's GamePigeon **Word Hunt** game.

It uses the `english-words` dataset and a depth-first search to find valid words on a Boggle-style board.

## Installation

```bash
pip install word-hunt-solver
```

## Usage
```bash
word-hunt-solver
```
